| get_rxnorm_map | R Documentation |
Get the RxNorm Map Between 2 TTY. This map ignores any variability from the rel/rela.
get_rxnorm_map(
conn,
conn_fun = "pg13::local_connect()",
from_tty = c("BN", "BPCK", "DF", "DFG", "ET", "GPCK", "IN", "MIN", "PIN", "PSN",
"SBD", "SBDC", "SBDF", "SBDG", "SCD", "SCDC", "SCDF", "SCDG", "SY", "TMSY"),
to_tty = c("BN", "BPCK", "DF", "DFG", "ET", "GPCK", "IN", "MIN", "PIN", "PSN", "SBD",
"SBDC", "SBDF", "SBDG", "SCD", "SCDC", "SCDF", "SCDG", "SY", "TMSY"),
full_path = FALSE,
schema = "umls",
verbose = TRUE,
render_sql = TRUE,
render_only = FALSE,
checks = ""
)
conn |
Database connection via DatabaseConnector. |
conn_fun |
Instead of supplying of a direct database connection, an expression can be supplied that automatically connects and disconnects the connection once the function is run. |
from_tty |
The RxNorm TTY to start from. |
to_tty |
The RxNorm TTY to end at. |
full_path |
By default, regardless of path length, only the |
schema |
For Postgres executions only, the schema to write all the tables to, Default: 'umls' |
verbose |
If TRUE, details on the activity are returned in the console, such as when the querying starting and was completed. |
render_sql |
If TRUE, the SQL statement for the operation is returned in the console. |
Tibble of the mappings between the aui, code, and str between
the two start and end tty arguments. If full_path is TRUE, the intermediate tty
values are also provided. Every set is prefixed with the tty value. The returned map
is derived from a full join and therefore, blank mappings between tty are also included
in the tibble.
Other RxNorm Map:
get_rxnorm_ingredient_map(),
get_rxnorm_tty_lookup(),
read_rxnorm_paths(),
setup_rxmap(),
write_rxnorm_map(),
write_rxnorm_path_lookup()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.