| run_setup | R Documentation |
Instantiate Postgres
run_setup(
conn,
conn_fun = "pg13::local_connect()",
schema = "umls",
path_to_rrfs,
steps = c("reset_schema", "ddl_tables", "copy_rrfs", "add_indexes", "log",
"setup_crosswalk"),
postprocess = TRUE,
mrconso_only = "DEPRECATED",
omop_only = "DEPRECATED",
english_only = TRUE,
log_schema = "public",
log_table_name = "setup_umls_log",
log_version,
log_release_date,
verbose = TRUE,
render_sql = TRUE,
render_only = FALSE
)
conn |
Database connection via DatabaseConnector. |
conn_fun |
Instead of supplying of a direct database connection, an expression can be supplied that automatically connects and disconnects the connection once the function is run. |
schema |
For Postgres executions only, the schema to write all the tables to, Default: 'umls' |
mrconso_only |
Setup only the MRCONSO Table? Default: FALSE |
omop_only |
Setup the MRCONSO, MRHIER, MRMAP, MRSMAP, MRSAT, AND MRREL Tables only? Default: FALSE |
english_only |
Setup only the ENG Tables? Default: TRUE |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.